#!/bin/bash

MKDIR="mkdir -p";
COPY_DIR="cp -rp";
MOUNT_CMD="mount -vv -t nfs4 -o rw,hard,nolock";

echo "executing mount script"

if [ "$1" = "$MOUNT_PARAM" ]
then
    echo "mounting";
    TEST_MOUNT_PATH="$CLUSTER_DATA_PATH/testmount";
    PROD_MOUNT_PATH="$CLUSTER_DATA_PATH/prodmount";
    $MKDIR $TEST_MOUNT_PATH;
    $MKDIR $PROD_MOUNT_PATH;

    echo "mounting $TESTCLUSTER_DEVICE_IP to $TEST_MOUNT_PATH"
    $MOUNT_CMD $TESTCLUSTER_DEVICE_IP:/ $TEST_MOUNT_PATH;
    err_code=$?

    if [ $err_code != 0 ] && [ "$PROD" != "true" ]
    then
        echo "could not mount test nfs; cmd exited with code $err_code";
        exit -1;
    elif [ $err_code != 0 ] && [ "$PROD" = "true" ]
    then
        echo "could not mount test nfs, exited with code $err_code but PROD=$PROD, skipping";
    fi

    echo "mounting $PRODCLUSTER_DEVICE_IP to $PROD_MOUNT_PATH"
    $MOUNT_CMD $PRODCLUSTER_DEVICE_IP:/ $PROD_MOUNT_PATH;
    err_code=$?

    if [ $err_code != 0 ] && [ "$PROD" = "true" ]
    then
        echo "could not mount prod nfs; cmd exited with code $err_code";
        exit -1;
    elif [ $err_code != 0 ] && [ "$PROD" != "true" ]
    then
        echo "could not mount prod nfs, exited with code $err_code but PROD=$PROD, skipping";
    fi

    shift 1;
    i=1; # first arg is script
    j=$#;
    while [ $i -le $j ] # iterate through arguments
    do
        DATA_PATH="$TEST_MOUNT_PATH/$1";
        SOURCE_DATA_PATH="$PROD_MOUNT_PATH/$1";

        if [ "$PROD" = "true" ]
        then
            DATA_PATH="$PROD_MOUNT_PATH/$1";
            SOURCE_DATA_PATH="$TEST_MOUNT_PATH/$1";
        fi

        if [[ "$1" == "--"* ]]
        then
            break;
        fi

        echo "$i: $DATA_PATH";

        if [ -d "$DATA_PATH" ] # directory exists
        then
        
            if [ -z "$(ls -A $DATA_PATH)" ] # is directory empty
            then
                if [ -d "$SOURCE_DATA_PATH" ] # source path exists
                then
                    if [ "$COPY_FILES" = "true" ]
                    then 
                        DESTINATION_DATA_PATH="$(dirname "$DATA_PATH")"
                        echo "copying $SOURCE_DATA_PATH to $DESTINATION_DATA_PATH"
                        $MKDIR $DATA_PATH;
                        $COPY_DIR "$SOURCE_DATA_PATH" $DESTINATION_DATA_PATH;
                        echo "copied source $SOURCE_DATA_PATH to $DESTINATION_DATA_PATH"
                    else
                        echo "COPY_FILES is false; skipping copy"
                    fi
                else
                    echo "cannot copy, source $SOURCE_DATA_PATH does not exist; skipping";
                fi
            else
                echo "$DATA_PATH is not empty; skipping copy data.";
            fi

        else
            if [ -d "$SOURCE_DATA_PATH" ] # source path exists
            then
                if [ "$COPY_FILES" = "true" ]
                then
                    DESTINATION_DATA_PATH="$(dirname "$DATA_PATH")"
                    echo "copying $SOURCE_DATA_PATH to $DESTINATION_DATA_PATH"
                    $MKDIR $DATA_PATH;
                    $COPY_DIR "$SOURCE_DATA_PATH" $DESTINATION_DATA_PATH;
                    echo "copied source $SOURCE_DATA_PATH to $DESTINATION_DATA_PATH"
                else
                    $MKDIR $DATA_PATH
                    echo "COPY_FILES is false; created empty dir"
                fi
            else
                $MKDIR $DATA_PATH
                echo "cannot copy, source $SOURCE_DATA_PATH does not exist; empty folder created";
            fi
        fi

        i=$((i + 1));
        shift 1;
    done

    if [ "$1" = "$REPOCOPY_PARAM" ]
    then
        shift 1;
        i=$((i + 1));
        while [ $i -le $j ] # iterate through arguments
        do
            DATA_PATH="$TEST_MOUNT_PATH";

            if [ "$PROD" = "true" ]
            then
                DATA_PATH="$PROD_MOUNT_PATH";
            fi

            if [[ "$1" == "--"* ]]
            then
                break;
            fi

            IFS=: read SOURCE DESTINATION <<< "$1"

            echo "copying $SOURCE from repo to $DESTINATION"
            cp $SOURCE "$DATA_PATH/$DESTINATION"
            echo "copied $SOURCE to $DESTINATION"

            i=$((i + 1));
            shift 1;
        done
    fi

    if [ "$1" = "$DELETE_FILE_PARAM" ]
    then
        shift 1;
        i=$((i + 1));
        while [ $i -le $j ] # iterate through arguments
        do
            DATA_PATH="$TEST_MOUNT_PATH";

            if [ "$PROD" = "true" ]
            then
                DATA_PATH="$PROD_MOUNT_PATH";
            fi

            if [[ "$1" == "--"* ]]
            then
                break;
            fi

            echo "deleting $1"
            rm -f "$DATA_PATH/$1"
            echo "$1 deleted"

            i=$((i + 1));
            shift 1;
        done
    fi

    if [ "$1" = "$CHMOD_FILE_PARAM" ]
    then
        shift 1;
        i=$((i + 1));
        while [ $i -le $j ] # iterate through arguments
        do
            DATA_PATH="$TEST_MOUNT_PATH";

            if [ "$PROD" = "true" ]
            then
                DATA_PATH="$PROD_MOUNT_PATH";
            fi

            if [[ "$1" == "--"* ]]
            then
                break;
            fi

            IFS=: read SOURCE LEVEL <<< "$1"

            echo "applying permissions $LEVEL to $SOURCE"
            chmod -f $LEVEL "$DATA_PATH/$SOURCE" || true

            i=$((i + 1));
            shift 1;
        done
    fi
fi



