import matrix_wrapper
from callback.Callback import Callback
from typing import Callable, Optional
import shlex
from callback.Callback import Callback
import traceback

_callbacks: dict = {}
_interactive_callback: Callback = None
_interactive: bool = False

    
async def get_single_param(args: dict, arg_name: str, pre_command: str, cast_class=str, required=True) -> str:
    arg_params = await get_multi_params(args, arg_name, pre_command, required)

    if arg_params is None:
        return None
    elif len(arg_params) != 1:
        await matrix_wrapper.send_html("<code>{}</code> needs arg <code>{}</code> exactly once".format(pre_command, arg_name))
        return None

    arg_param = arg_params.pop(0)

    try:
        return cast_class(arg_param)
    except (ValueError, TypeError):
        await matrix_wrapper.send_html("<code{} {}<code> needs floating point number as param".format(pre_command, arg_name))

async def get_multi_params(args: dict, arg_name: str, pre_command: str, required=True) -> list[str]:
    arg_params: list[str] = args.get(arg_name)

    if arg_params is None and required:
        await matrix_wrapper.send_html("<code>{}</code> needs arg <code>{}</code>".format(pre_command, arg_name))
    
    return arg_params

def parse_args(args: list[str]):
    parsed_args = {}

    if not args:
        return parsed_args

    current_arg = Callback.NO_PARAM
    parsed_args.update({current_arg: []})
    while args:
        value = args.pop(0)
        if value.startswith("-"):
            current_arg = value
            parsed_args.update({current_arg: []})
        else:
            elements = parsed_args.get(current_arg)
            if elements is None:
                elements = []
            elements.append(value)
            parsed_args.update({current_arg: elements})

    return parsed_args

async def exec(args: list[str]):
    global _callbacks, _interactive_callback, _interactive

    if not args:
        await matrix_wrapper.send_message("no command provided")
        return

    callback: Callback = None
    if _interactive:
        callback = _interactive_callback
    else:
        fnc_name = args.pop(0)
        callback = _callbacks.get(fnc_name)
        if callback is None:
            await matrix_wrapper.send_message("command {{{}}} not understood, please try again".format(fnc_name))
            return

    try:
        await callback().run(parse_args(args))
    except Exception:
        await(matrix_wrapper.send_html("someting went wrong in the code<br/><code>{}</code>".format(traceback.format_exc())))

def set_interactive(interactive: bool, callback: Callback):
    _interactive = interactive
    _interactive_callback = callback

# def register(id: str, callback: Callable[[list[str],], Optional[None]]):
def register(id: str, callback: Callback):
    global _callbacks

    _callbacks.update({id: callback})

def unpack(message: str):
    msg = message.strip()
    if msg.startswith("*"):
        msg = msg.removeprefix("*")
        msg = msg.strip()
    return shlex.split(msg)